@@ -448,6 +448,14 @@ class ElasticSearchVisitor(Visitor):
 
         return query
 
+    def _generate_wildcard_query(self, value, fieldnames):
+        if not fieldnames:
+            fieldnames = ['_all']
+        if not isinstance(fieldnames, list):
+            fieldnames = [fieldnames]
+        should_query = [{"wildcard": {field: {"value": value}}} for field in fieldnames]
+        return wrap_queries_in_bool_clauses_if_more_than_one(should_query, use_must_clause=False)
+
     # TODO Move it to visitor utils and write tests for it.
     def _generate_term_query(self, fieldname, value, boost=None):
         if not boost:
@@ -753,17 +761,15 @@ class ElasticSearchVisitor(Visitor):
                 bai_field_variation=FieldVariations.search,
                 query_bai_field_if_dots_in_name=True
             )
-            query = self._generate_query_string_query(
+            query = self._generate_wildcard_query(
                 node.value,
-                fieldnames=bai_fieldnames or fieldnames,
-                analyze_wildcard=True
+                fieldnames=bai_fieldnames or fieldnames
             )
             return self._generate_nested_author_query(query, fieldnames)
 
-        query = self._generate_query_string_query(
+        query = self._generate_wildcard_query(
             node.value,
-            fieldnames=fieldnames,
-            analyze_wildcard=True
+            fieldnames=fieldnames
         )
         return query
 
@@ -890,7 +896,7 @@ class ElasticSearchVisitor(Visitor):
                 )
         elif self._are_fieldnames_author_or_first_author(fieldnames):
             exact_match_queries = [
-                self._generate_nested_author_query({'term': {field: node.value}}, fieldnames)
+                self._generate_nested_author_query({'match_phrase': {field: node.value}}, fieldnames)
                 for field in (bai_fieldnames or fieldnames)
             ]
         else:
@@ -932,9 +938,7 @@ class ElasticSearchVisitor(Visitor):
             query_bai_field_if_dots_in_name=True
         )
 
-        query = self._generate_query_string_query(value,
-                                                  fieldnames=bai_fieldnames or fieldnames,
-                                                  analyze_wildcard=True)
+        query = self._generate_wildcard_query(value, fieldnames=bai_fieldnames or fieldnames)
         if self._are_fieldnames_author_or_first_author(bai_fieldnames) or self._are_fieldnames_author_or_first_author(fieldnames):
             return self._generate_nested_author_query(query, fieldnames)
 
